==> visionegg-1.1.dev-r1433.zip: visionegg-1.1.dev-r1433/doc/reference/make_epy.sh <==
#!/bin/sh
if test ! -n "$PYTHON"; then
  echo "Specify which python with the PYTHON environment variable"
  exit 1
fi

$PYTHON epydoc --name "Vision Egg" --url "http://www.visionegg.org" --no-private \
--docformat plaintext \
VisionEgg \
VisionEgg.Configuration \
VisionEgg.Core \
VisionEgg.Daq \
VisionEgg.DaqLPT \
VisionEgg.DaqOverTCP \
VisionEgg.Deprecated \
VisionEgg.Dots \
VisionEgg.FlowControl \
VisionEgg.FlowControl \
VisionEgg.GUI \
VisionEgg.Gratings \
VisionEgg.Lib3DS \
VisionEgg.MoreStimuli \
VisionEgg.ParameterTypes \
VisionEgg.PlatformDependent \
VisionEgg.PyroClient \
VisionEgg.PyroHelpers \
VisionEgg.QuickTime \
VisionEgg.SphereMap \
VisionEgg.TCPController \
VisionEgg.Text \
VisionEgg.Textures \
VisionEgg.ThreeDeeMath \
VisionEgg.darwin_getrefresh \
VisionEgg.darwin_maxpriority \
VisionEgg.gl_qt \
VisionEgg.posix_maxpriority \
VisionEgg.win32_getrefresh \
VisionEgg.win32_maxpriority

#VisionEgg.GL \
#VisionEgg.GLTrace \

#VisionEgg.PyroApps \
#VisionEgg.PyroApps.ColorCalGUI \
#VisionEgg.PyroApps.ColorCalServer \
#VisionEgg.PyroApps.EPhysGUI \
#VisionEgg.PyroApps.EPhysGUIUtils \
#$PYTHON pydoc.py -w VisionEgg.PyroApps.EPhysServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.FlatGratingGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.FlatGratingServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.GridGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.GridServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.MouseTargetGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.MouseTargetServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.ScreenPositionGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.ScreenPositionServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SphereGratingGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SphereGratingServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SpinningDrumGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SpinningDrumServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.TargetGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.TargetServer

==> visionegg-1.1.2.zip: visionegg-1.1.2/doc/reference/make_epy.sh <==
#!/bin/sh
python epydoc --name "Vision Egg" --url "http://www.visionegg.org" --no-private \
--docformat plaintext --parse-only \
VisionEgg \
VisionEgg.Configuration \
VisionEgg.Core \
VisionEgg.Daq \
VisionEgg.DaqLPT \
VisionEgg.Deprecated \
VisionEgg.Dots \
VisionEgg.FlowControl \
VisionEgg.GUI \
VisionEgg.Gratings \
VisionEgg.MoreStimuli \
VisionEgg.ParameterTypes \
VisionEgg.PlatformDependent \
VisionEgg.PyroClient \
VisionEgg.PyroHelpers \
VisionEgg.QuickTime \
VisionEgg.SphereMap \
VisionEgg.TCPController \
VisionEgg.Text \
VisionEgg.Textures \
VisionEgg.ThreeDeeMath \
VisionEgg.darwin_getrefresh \
VisionEgg.darwin_maxpriority \
VisionEgg.gl_qt \
VisionEgg.posix_maxpriority \
VisionEgg.win32_getrefresh \
VisionEgg.win32_maxpriority

#VisionEgg.GL \
#VisionEgg.GLTrace \

#VisionEgg.PyroApps \
#VisionEgg.PyroApps.ColorCalGUI \
#VisionEgg.PyroApps.ColorCalServer \
#VisionEgg.PyroApps.EPhysGUI \
#VisionEgg.PyroApps.EPhysGUIUtils \
#$PYTHON pydoc.py -w VisionEgg.PyroApps.EPhysServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.FlatGratingGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.FlatGratingServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.GridGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.GridServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.MouseTargetGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.MouseTargetServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.ScreenPositionGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.ScreenPositionServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SphereGratingGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SphereGratingServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SpinningDrumGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.SpinningDrumServer
#$PYTHON pydoc.py -w VisionEgg.PyroApps.TargetGUI
#$PYTHON pydoc.py -w VisionEgg.PyroApps.TargetServer
